/*==============================================================*/
/* Database name:  axyl                                         */
/* DBMS name:      PostgreSQL 7                                 */
/* Created on:     9/02/2005 4:53:22 p.m.                       */
/*==============================================================*/



CREATE FUNCTION "modstamp" () RETURNS opaque AS 'BEGIN NEW.last_modified := CURRENT_TIMESTAMP; RETURN NEW; END; '
LANGUAGE 'plpgsql';


create trigger ax_block_modstamp before update on ax_block
   for each row execute procedure modstamp();


create trigger ax_forum_msg_modstamp before update on ax_forum_msg
   for each row execute procedure modstamp();


create trigger ax_layout_modstamp before update on ax_layout
   for each row execute procedure modstamp();


create trigger ax_menu_modstamp before update on ax_menu
   for each row execute procedure modstamp();


create trigger ax_menuoption_modstamp before update on ax_menuoption
   for each row execute procedure modstamp();


create trigger ax_microsite_modstamp before update on ax_microsite
   for each row execute procedure modstamp();


create trigger ax_story_modstamp before update on ax_story
   for each row execute procedure modstamp();

